> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Heartrate 3 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC32
```
#include <stdint.h>
#include "heartrate_3.h"

// HeartRate 3 GPIO
sbit RST at RC1_bit;
sbit RST_DIR at TRISC1_bit;

void system_setup( void );
static void Display_Init( void );
void interrupt_setup( void );

uint16_t g_count = 0;
uint8_t int_flag = 0;
uint16_t time_count = 0;

void system_setup( void )
{
    //Local Declarations
    char            text[40] = { 0 };
    dynamic_modes_t dynamic_modes;
    uint8_t         address = 0x58;

    //Set up dynamic modes for Heart Rate 3 Initialization
    dynamic_modes.transmit = trans_en;
    dynamic_modes.curr_range = led_norm;
    dynamic_modes.adc_power = adc_on;
    dynamic_modes.clk_mode = osc_mode;
    dynamic_modes.tia_power = tia_off;
    dynamic_modes.rest_of_adc = rest_of_adc_on;
    dynamic_modes.afe_rx_mode = afe_rx_normal;
    dynamic_modes.afe_mode = afe_normal;

    //GPIO setup
    RST_DIR = 0;

    //UART Initialize
    UART2_Init( 9600 );
    UART2_Write_Text( "UART is Initialized\r\n" );

    //Toggle Reset pin
    RST = 0;
    Delay_us(50);
    RST = 1;

    // TWI
    I2C1_Init_Advanced( 50000, 100000 );
    UART2_Write_Text( "I2C Initialized\r\n" );

    //Heart Rate 3 Initialize
    hr3_init( address, &dynamic_modes );
    UART2_Write_Text( "HR3 Initialized\r\n" );

    initStatHRM();      // Initializes values to 0
    interrupt_setup();

}

void interrupt_setup( void )
{
    TRISE8_bit = 1;                    // Set RE8 pin as input
    INT1IP0_bit = 0;                   // Set INT0 interrupt
    INT1IP1_bit = 1;                   // Set interrupt priorities
    INT1IP2_bit = 1;                   // Set inrrupt priority to 4
    INT1IE_bit  = 1;                   // Set interrupt on INT0 (RE8) to be enabled
    EnableInterrupts();                // Enable interruts as previously set
}

void adc_rdy_isr() iv IVT_EXTERNAL_1 ilevel 5 ics ICS_AUTO
{
    int_flag = 1;
    INT1IF_bit = 0;                    // Reset INT2 flag
}

```

```
void main()
{   //Local Declarations
    uint16_t   rate     = 0;
    uint32_t led1 = 0;
    char  uart_text[15] = {0};

    system_setup();     // GPIO / HeartRate 3 / UART / I2C Setups / Interrupt / BPM Algorithm
    Delay_ms(200);

    while (1)
    {
        if ( int_flag == 1 )
        {
            statHRMAlgo( hr3_get_led1_val() );
            int_flag = 0;
            rate = hr3_get_heartrate();                                   // Gets current Heartrate

            IntToStr( rate, uart_text );
            UART2_Write_Text( uart_text );
            UART2_Write(13);
            UART2_Write(10);
        }
    }
}

```

