#include <stdint.h>
#include "heartrate_3.h"

// HeartRate 3 GPIO
sbit RST at RC1_bit;
sbit RST_DIR at TRISC1_bit;

void system_setup( void );
static void Display_Init( void );

void main()
{    //Local Declarations
     uint16_t   rate     = 0;
     char  uart_text[15] = {0};

     system_setup();     // GPIO / HeartRate 3 / UART / I2C Setups
     Delay_ms(200);

     initStatHRM();      // Initializes values to 0

       while(1)
       {
          rate = hr3_get_heartrate();                                   // Gets current Heartrate

          sprintl( uart_text, "HeartRate: %llu", rate );                // Display Heartrate on UART
          UART1_Write_Text( uart_text );
          UART1_Write(13);
          UART1_Write(10);

          Delay_ms(10);
       }

}

void system_setup( void )
{
       //Local Declarations
     char            text[40] = { 0 };
     dynamic_modes_t dynamic_modes;
     uint8_t         address = 0x58;

        //Set up dynamic modes for Heart Rate 3 Initialization
     dynamic_modes.transmit = trans_en;
     dynamic_modes.curr_range = led_norm;
     dynamic_modes.adc_power = adc_on;
     dynamic_modes.clk_mode = osc_mode;
     dynamic_modes.tia_power = tia_off;
     dynamic_modes.rest_of_adc = rest_of_adc_on;
     dynamic_modes.afe_rx_mode = afe_rx_normal;
     dynamic_modes.afe_mode = afe_normal;

       //GPIO setup
     RST_DIR = 0;

       //UART Initialize
     UART1_Init( 9600 );
     UART1_Write_Text( "UART is Initialized\r\n" );

       //Toggle Reset pin
     RST = 0;
     Delay_us(50);
     RST = 1;

       //I2C Initialize
     I2C1_Init(100000);
     UART1_Write_Text( "I2C Initialized\r\n" );

       //Heart Rate 3 Initialize
     hr3_init( address, &dynamic_modes );

}